==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/et/admin/statuslabels/message.php <==
<?php

return array(

    'does_not_exist' => 'Olekumärki pole olemas.',
    'assoc_assets'	 => 'See olekuala märgis on praegu seotud vähemalt ühe varaga ja seda ei saa kustutada. Palun uuendage oma vara, et seda olekut enam mitte näidata, ja proovige uuesti.',


    'create' => array(
        'error'   => 'Olekumärki ei loodud, proovige uuesti.',
        'success' => 'Olekuriba loodud edukalt.'
    ),

    'update' => array(
        'error'   => 'Oleku märgist ei värskendatud, proovige uuesti',
        'success' => 'Oleku märgis uuendati edukalt.'
    ),

    'delete' => array(
        'confirm'   => 'Kas olete kindel, et soovite selle oleku märgendi kustutada?',
        'error'   => 'Staatuse märgi kustutamisel tekkis probleem. Palun proovi uuesti.',
        'success' => 'Staatuse märgis kustutati edukalt.'
    ),

    'help' => array(
        'undeployable'   => 'Neid varasid ei saa kellelegi anda.',
        'deployable'   => 'Neid varasid saab kontrollida. Kui need on määratud, eeldatakse, et nad on meta-olekuga <i class="fa fa-circle text-blue"></i> <strong>kasutatud</strong>.',
        'archived'   => 'Neid varasid ei saa kontrollida ja need kuvatakse ainult arhiivitud vaates. See on kasulik, kui säilitada teavet varade kohta eelarve koostamiseks / ajalooliste eesmärkide saavutamiseks, kuid hoida neid igapäevase varade loendist välja.',
        'pending'   => 'Neid varasid ei saa veel kellelegi määrata, neid kasutatakse sageli esemete puhul, mis remonti vajavad, kuid eeldatavalt ringlusse.',
    ),

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/et/admin/statuslabels/message.php <==
<?php

return [

    'does_not_exist' => 'Olekumärki pole olemas.',
    'assoc_assets'	 => 'See olekuala märgis on praegu seotud vähemalt ühe varaga ja seda ei saa kustutada. Palun uuendage oma vara, et seda olekut enam mitte näidata, ja proovige uuesti.',

    'create' => [
        'error'   => 'Olekumärki ei loodud, proovige uuesti.',
        'success' => 'Olekuriba loodud edukalt.',
    ],

    'update' => [
        'error'   => 'Oleku märgist ei värskendatud, proovige uuesti',
        'success' => 'Oleku märgis uuendati edukalt.',
    ],

    'delete' => [
        'confirm'   => 'Kas olete kindel, et soovite selle oleku märgendi kustutada?',
        'error'   => 'Staatuse märgi kustutamisel tekkis probleem. Palun proovi uuesti.',
        'success' => 'Staatuse märgis kustutati edukalt.',
    ],

    'help' => [
        'undeployable'   => 'Neid varasid ei saa kellelegi anda.',
        'deployable'   => 'These assets can be checked out. Once they are assigned, they will assume a meta status of <i class="fas fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Neid varasid ei saa kontrollida ja need kuvatakse ainult arhiivitud vaates. See on kasulik, kui säilitada teavet varade kohta eelarve koostamiseks / ajalooliste eesmärkide saavutamiseks, kuid hoida neid igapäevase varade loendist välja.',
        'pending'   => 'Neid varasid ei saa veel kellelegi määrata, neid kasutatakse sageli esemete puhul, mis remonti vajavad, kuid eeldatavalt ringlusse.',
    ],

];
